aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/elna/boot/ast.h7
-rw-r--r--include/elna/gcc/elna-generic.h2
2 files changed, 5 insertions, 4 deletions
diff --git a/include/elna/gcc/elna-generic.h b/include/elna/gcc/elna-generic.h
index eec6cb4..d67f3c9 100644
--- a/include/elna/gcc/elna-generic.h
+++ b/include/elna/gcc/elna-generic.h
@@ -58,7 +58,7 @@ namespace elna::gcc
void build_case_general(boot::case_statement *statement, tree condition_expression);
void build_procedure_call(location_t call_location,
tree procedure_address, const std::vector<boot::expression *>& arguments,
- const std::vector<boot::type>& variadic_types);
+ const std::vector<boot::type>& argument_types);
bool build_builtin_procedures(boot::procedure_call *call);
void build_assert_builtin(location_t call_location, const std::vector<boot::expression *>& arguments);
diff --git a/include/elna/boot/ast.h b/include/elna/boot/ast.h
index 8f5d863..0fc5e32 100644
--- a/include/elna/boot/ast.h
+++ b/include/elna/boot/ast.h
@@ -913,9 +913,10 @@ namespace elna::boot
public:
std::vector<expression *> arguments;
- /// Types the arguments after the parameters of a variadic procedure
- /// are passed as, set by the type checker.
- std::vector<type> variadic_types;
+ /// The type each argument is passed as: the type of the parameter it
+ /// binds to, or the type it is promoted to when it follows the
+ /// parameters of a variadic procedure. Set by the type checker.
+ std::vector<type> argument_types;
procedure_call(const source_position position, designator_expression *callable,
std::vector<expression *>&& arguments);